---
title: <span class="badge object-type-scalar"></span> KilometersPerHour
---
# <span class="badge object-type-scalar"></span> KilometersPerHour

Velocity: kilometers/hour (km/h)

## Definition

```python
# Velocity: kilometers/hour (km/h)
KilometersPerHour: typing.Literal["velocitykmh"] = "velocitykmh"
```
